/****************************************************************************
** Meta object code from reading C++ file 'mainwindow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.9.2)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../Heimdall-v2.2.2/heimdall-frontend/source/mainwindow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mainwindow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.9.2. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t {};
} // unnamed namespace

template <> constexpr inline auto HeimdallFrontend::MainWindow::qt_create_metaobjectdata<qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "HeimdallFrontend::MainWindow",
        "OpenDonationWebpage",
        "",
        "SetVerboseOutput",
        "enabled",
        "ShowAbout",
        "FunctionTabChanged",
        "index",
        "SelectFirmwarePackage",
        "OpenDeveloperHomepage",
        "OpenDeveloperDonationWebpage",
        "LoadFirmwarePackage",
        "SelectPartitionName",
        "SelectPartitionFile",
        "SelectPartition",
        "row",
        "AddPartition",
        "RemovePartition",
        "SelectPit",
        "SetRepartition",
        "SetNoReboot",
        "SetResume",
        "SetWaitForDevice",
        "StartFlash",
        "FirmwareNameChanged",
        "text",
        "FirmwareVersionChanged",
        "PlatformNameChanged",
        "PlatformVersionChanged",
        "HomepageUrlChanged",
        "DonateUrlChanged",
        "DeveloperNameChanged",
        "SelectDeveloper",
        "AddDeveloper",
        "RemoveDeveloper",
        "DeviceInfoChanged",
        "SelectDevice",
        "AddDevice",
        "RemoveDevice",
        "BuildPackage",
        "DetectDevice",
        "ClosePcScreen",
        "SelectPitDestination",
        "DownloadPit",
        "DevicePrintPitToggled",
        "checked",
        "LocalFilePrintPitToggled",
        "SelectPrintPitFile",
        "PrintPit",
        "HandleHeimdallStdout",
        "HandleHeimdallReturned",
        "exitCode",
        "QProcess::ExitStatus",
        "exitStatus",
        "HandleHeimdallError",
        "QProcess::ProcessError",
        "error"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'OpenDonationWebpage'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetVerboseOutput'
        QtMocHelpers::SlotData<void(bool)>(3, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'ShowAbout'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'FunctionTabChanged'
        QtMocHelpers::SlotData<void(int)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'SelectFirmwarePackage'
        QtMocHelpers::SlotData<void()>(8, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'OpenDeveloperHomepage'
        QtMocHelpers::SlotData<void()>(9, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'OpenDeveloperDonationWebpage'
        QtMocHelpers::SlotData<void()>(10, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'LoadFirmwarePackage'
        QtMocHelpers::SlotData<void()>(11, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SelectPartitionName'
        QtMocHelpers::SlotData<void(int)>(12, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 7 },
        }}),
        // Slot 'SelectPartitionFile'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SelectPartition'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'AddPartition'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RemovePartition'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SelectPit'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SetRepartition'
        QtMocHelpers::SlotData<void(int)>(19, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'SetNoReboot'
        QtMocHelpers::SlotData<void(int)>(20, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'SetResume'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'SetResume'
        QtMocHelpers::SlotData<void(int)>(21, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'SetWaitForDevice'
        QtMocHelpers::SlotData<void(bool)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 4 },
        }}),
        // Slot 'SetWaitForDevice'
        QtMocHelpers::SlotData<void(int)>(22, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 4 },
        }}),
        // Slot 'StartFlash'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'FirmwareNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(24, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'FirmwareVersionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(26, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'PlatformNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(27, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'PlatformVersionChanged'
        QtMocHelpers::SlotData<void(const QString &)>(28, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'HomepageUrlChanged'
        QtMocHelpers::SlotData<void(const QString &)>(29, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'DonateUrlChanged'
        QtMocHelpers::SlotData<void(const QString &)>(30, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'DeveloperNameChanged'
        QtMocHelpers::SlotData<void(const QString &)>(31, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'SelectDeveloper'
        QtMocHelpers::SlotData<void(int)>(32, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'AddDeveloper'
        QtMocHelpers::SlotData<void()>(33, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RemoveDeveloper'
        QtMocHelpers::SlotData<void()>(34, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DeviceInfoChanged'
        QtMocHelpers::SlotData<void(const QString &)>(35, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 25 },
        }}),
        // Slot 'SelectDevice'
        QtMocHelpers::SlotData<void(int)>(36, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'AddDevice'
        QtMocHelpers::SlotData<void()>(37, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'RemoveDevice'
        QtMocHelpers::SlotData<void()>(38, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'BuildPackage'
        QtMocHelpers::SlotData<void()>(39, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DetectDevice'
        QtMocHelpers::SlotData<void()>(40, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'ClosePcScreen'
        QtMocHelpers::SlotData<void()>(41, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'SelectPitDestination'
        QtMocHelpers::SlotData<void()>(42, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DownloadPit'
        QtMocHelpers::SlotData<void()>(43, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'DevicePrintPitToggled'
        QtMocHelpers::SlotData<void(bool)>(44, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'LocalFilePrintPitToggled'
        QtMocHelpers::SlotData<void(bool)>(46, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 45 },
        }}),
        // Slot 'SelectPrintPitFile'
        QtMocHelpers::SlotData<void()>(47, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'PrintPit'
        QtMocHelpers::SlotData<void()>(48, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'HandleHeimdallStdout'
        QtMocHelpers::SlotData<void()>(49, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'HandleHeimdallReturned'
        QtMocHelpers::SlotData<void(int, QProcess::ExitStatus)>(50, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 51 }, { 0x80000000 | 52, 53 },
        }}),
        // Slot 'HandleHeimdallError'
        QtMocHelpers::SlotData<void(QProcess::ProcessError)>(54, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 55, 56 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MainWindow, qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject HeimdallFrontend::MainWindow::staticMetaObject = { {
    QMetaObject::SuperData::link<QMainWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t>.metaTypes,
    nullptr
} };

void HeimdallFrontend::MainWindow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MainWindow *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->OpenDonationWebpage(); break;
        case 1: _t->SetVerboseOutput((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 2: _t->ShowAbout(); break;
        case 3: _t->FunctionTabChanged((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 4: _t->SelectFirmwarePackage(); break;
        case 5: _t->OpenDeveloperHomepage(); break;
        case 6: _t->OpenDeveloperDonationWebpage(); break;
        case 7: _t->LoadFirmwarePackage(); break;
        case 8: _t->SelectPartitionName((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 9: _t->SelectPartitionFile(); break;
        case 10: _t->SelectPartition((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->AddPartition(); break;
        case 12: _t->RemovePartition(); break;
        case 13: _t->SelectPit(); break;
        case 14: _t->SetRepartition((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 15: _t->SetNoReboot((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 16: _t->SetResume((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 17: _t->SetResume((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 18: _t->SetWaitForDevice((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 19: _t->SetWaitForDevice((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 20: _t->StartFlash(); break;
        case 21: _t->FirmwareNameChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 22: _t->FirmwareVersionChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 23: _t->PlatformNameChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 24: _t->PlatformVersionChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 25: _t->HomepageUrlChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 26: _t->DonateUrlChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 27: _t->DeveloperNameChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 28: _t->SelectDeveloper((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 29: _t->AddDeveloper(); break;
        case 30: _t->RemoveDeveloper(); break;
        case 31: _t->DeviceInfoChanged((*reinterpret_cast< std::add_pointer_t<QString>>(_a[1]))); break;
        case 32: _t->SelectDevice((*reinterpret_cast< std::add_pointer_t<int>>(_a[1]))); break;
        case 33: _t->AddDevice(); break;
        case 34: _t->RemoveDevice(); break;
        case 35: _t->BuildPackage(); break;
        case 36: _t->DetectDevice(); break;
        case 37: _t->ClosePcScreen(); break;
        case 38: _t->SelectPitDestination(); break;
        case 39: _t->DownloadPit(); break;
        case 40: _t->DevicePrintPitToggled((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 41: _t->LocalFilePrintPitToggled((*reinterpret_cast< std::add_pointer_t<bool>>(_a[1]))); break;
        case 42: _t->SelectPrintPitFile(); break;
        case 43: _t->PrintPit(); break;
        case 44: _t->HandleHeimdallStdout(); break;
        case 45: _t->HandleHeimdallReturned((*reinterpret_cast< std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast< std::add_pointer_t<QProcess::ExitStatus>>(_a[2]))); break;
        case 46: _t->HandleHeimdallError((*reinterpret_cast< std::add_pointer_t<QProcess::ProcessError>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *HeimdallFrontend::MainWindow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *HeimdallFrontend::MainWindow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN16HeimdallFrontend10MainWindowE_t>.strings))
        return static_cast<void*>(this);
    if (!strcmp(_clname, "Ui::MainWindow"))
        return static_cast< Ui::MainWindow*>(this);
    return QMainWindow::qt_metacast(_clname);
}

int HeimdallFrontend::MainWindow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMainWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 47)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 47;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 47)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 47;
    }
    return _id;
}
QT_WARNING_POP
