/********************************************************************************
** Form generated from reading UI file 'aboutform.ui'
**
** Created by: Qt User Interface Compiler version 6.9.2
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ABOUTFORM_H
#define UI_ABOUTFORM_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QScrollArea>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_AboutForm
{
public:
    QPushButton *okPushButton;
    QScrollArea *scrollArea;
    QWidget *scrollAreaWidgetContents;
    QVBoxLayout *verticalLayout_2;
    QVBoxLayout *verticalLayout;
    QLabel *versionCopyrightLabel;
    QSpacerItem *verticalSpacer_4;
    QLabel *label_6;
    QLabel *label_4;
    QLabel *label;
    QSpacerItem *verticalSpacer_2;
    QLabel *label_5;
    QSpacerItem *verticalSpacer;
    QLabel *label_7;
    QSpacerItem *verticalSpacer_3;
    QLabel *label_8;

    void setupUi(QWidget *AboutForm)
    {
        if (AboutForm->objectName().isEmpty())
            AboutForm->setObjectName("AboutForm");
        AboutForm->setWindowModality(Qt::WindowModality::ApplicationModal);
        AboutForm->resize(581, 491);
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(AboutForm->sizePolicy().hasHeightForWidth());
        AboutForm->setSizePolicy(sizePolicy);
        AboutForm->setMinimumSize(QSize(581, 491));
        AboutForm->setMaximumSize(QSize(581, 491));
        okPushButton = new QPushButton(AboutForm);
        okPushButton->setObjectName("okPushButton");
        okPushButton->setGeometry(QRect(250, 460, 75, 21));
        scrollArea = new QScrollArea(AboutForm);
        scrollArea->setObjectName("scrollArea");
        scrollArea->setGeometry(QRect(10, 10, 561, 441));
        QSizePolicy sizePolicy1(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Minimum);
        sizePolicy1.setHorizontalStretch(0);
        sizePolicy1.setVerticalStretch(0);
        sizePolicy1.setHeightForWidth(scrollArea->sizePolicy().hasHeightForWidth());
        scrollArea->setSizePolicy(sizePolicy1);
        scrollArea->setHorizontalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
        scrollArea->setWidgetResizable(true);
        scrollAreaWidgetContents = new QWidget();
        scrollAreaWidgetContents->setObjectName("scrollAreaWidgetContents");
        scrollAreaWidgetContents->setGeometry(QRect(0, -763, 545, 1202));
        QSizePolicy sizePolicy2(QSizePolicy::Policy::Preferred, QSizePolicy::Policy::Preferred);
        sizePolicy2.setHorizontalStretch(0);
        sizePolicy2.setVerticalStretch(0);
        sizePolicy2.setHeightForWidth(scrollAreaWidgetContents->sizePolicy().hasHeightForWidth());
        scrollAreaWidgetContents->setSizePolicy(sizePolicy2);
        scrollAreaWidgetContents->setMaximumSize(QSize(16777215, 16777215));
        verticalLayout_2 = new QVBoxLayout(scrollAreaWidgetContents);
        verticalLayout_2->setObjectName("verticalLayout_2");
        verticalLayout = new QVBoxLayout();
        verticalLayout->setObjectName("verticalLayout");
        verticalLayout->setContentsMargins(-1, -1, 0, -1);
        versionCopyrightLabel = new QLabel(scrollAreaWidgetContents);
        versionCopyrightLabel->setObjectName("versionCopyrightLabel");
        sizePolicy2.setHeightForWidth(versionCopyrightLabel->sizePolicy().hasHeightForWidth());
        versionCopyrightLabel->setSizePolicy(sizePolicy2);
        QFont font;
        font.setPointSize(10);
        versionCopyrightLabel->setFont(font);
        versionCopyrightLabel->setTextFormat(Qt::TextFormat::RichText);
        versionCopyrightLabel->setScaledContents(true);
        versionCopyrightLabel->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        versionCopyrightLabel->setWordWrap(true);
        versionCopyrightLabel->setOpenExternalLinks(false);

        verticalLayout->addWidget(versionCopyrightLabel);

        verticalSpacer_4 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_4);

        label_6 = new QLabel(scrollAreaWidgetContents);
        label_6->setObjectName("label_6");
        label_6->setFont(font);
        label_6->setTextFormat(Qt::TextFormat::RichText);
        label_6->setScaledContents(true);
        label_6->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        label_6->setWordWrap(true);
        label_6->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_6);

        label_4 = new QLabel(scrollAreaWidgetContents);
        label_4->setObjectName("label_4");
        label_4->setFont(font);
        label_4->setTextFormat(Qt::TextFormat::RichText);
        label_4->setScaledContents(true);
        label_4->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        label_4->setWordWrap(true);
        label_4->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_4);

        label = new QLabel(scrollAreaWidgetContents);
        label->setObjectName("label");
        QFont font1;
        font1.setPointSize(9);
        font1.setKerning(true);
        label->setFont(font1);
        label->setAutoFillBackground(false);
        label->setFrameShape(QFrame::Shape::NoFrame);
        label->setFrameShadow(QFrame::Shadow::Plain);
        label->setTextFormat(Qt::TextFormat::RichText);
        label->setScaledContents(true);
        label->setAlignment(Qt::AlignmentFlag::AlignLeading|Qt::AlignmentFlag::AlignLeft|Qt::AlignmentFlag::AlignTop);
        label->setWordWrap(true);
        label->setMargin(0);
        label->setIndent(2);
        label->setOpenExternalLinks(false);

        verticalLayout->addWidget(label);

        verticalSpacer_2 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_2);

        label_5 = new QLabel(scrollAreaWidgetContents);
        label_5->setObjectName("label_5");
        label_5->setTextFormat(Qt::TextFormat::RichText);
        label_5->setWordWrap(true);
        label_5->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_5);

        verticalSpacer = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer);

        label_7 = new QLabel(scrollAreaWidgetContents);
        label_7->setObjectName("label_7");
        label_7->setTextFormat(Qt::TextFormat::RichText);
        label_7->setWordWrap(true);
        label_7->setOpenExternalLinks(false);

        verticalLayout->addWidget(label_7);

        verticalSpacer_3 = new QSpacerItem(20, 15, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        verticalLayout->addItem(verticalSpacer_3);

        label_8 = new QLabel(scrollAreaWidgetContents);
        label_8->setObjectName("label_8");
        label_8->setTextFormat(Qt::TextFormat::RichText);
        label_8->setWordWrap(true);
        label_8->setOpenExternalLinks(true);

        verticalLayout->addWidget(label_8);


        verticalLayout_2->addLayout(verticalLayout);

        scrollArea->setWidget(scrollAreaWidgetContents);

        retranslateUi(AboutForm);
        QObject::connect(okPushButton, &QPushButton::clicked, AboutForm, qOverload<>(&QWidget::close));

        QMetaObject::connectSlotsByName(AboutForm);
    } // setupUi

    void retranslateUi(QWidget *AboutForm)
    {
        AboutForm->setWindowTitle(QCoreApplication::translate("AboutForm", "About Heimdall Frontend", nullptr));
        okPushButton->setText(QCoreApplication::translate("AboutForm", "OK", nullptr));
        versionCopyrightLabel->setText(QCoreApplication::translate("AboutForm", "<html><head/><body><p><span style=\" font-family:'MS Shell Dlg 2'; font-weight:600;\">Heimdall Frontend</span></p><p><span style=\" font-family:'MS Shell Dlg 2';\">%HEIMDALL-VERSION%</span></p><p><span style=\" font-family:'MS Shell Dlg 2';\">Copyright \302\251 2010-2017 Benjamin Dobell, Glass Echidna</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-weight:600;\">Heimdall (command line)</span></p><p><span style=\" font-family:'MS Shell Dlg 2';\">%HEIMDALL-VERSION%</span></p><p><span style=\" font-family:'MS Shell Dlg 2';\">Copyright \302\251 2010-2017 Benjamin Dobell, Glass Echidna</span></p><p><span style=\" font-family:'MS Shell Dlg 2';\">Copyright \302\251 2021-2024 Henrik Grimler</span></p></body></html>", nullptr));
        label_6->setText(QCoreApplication::translate("AboutForm", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Lucida Grande'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; font-weight:600;\">Glass Echidna Homepage:</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><a href=\"https://www.glassechidna.com.au/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; text-decoration: underline; color:#0000ff;\">https://www.glassechidna.com.au/</span></a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-in"
                        "dent:0; text-indent:0px; font-family:'MS Shell Dlg 2'; font-size:10pt; text-decoration: underline; color:#0000ff;\"></p></body></html>", nullptr));
        label_4->setText(QCoreApplication::translate("AboutForm", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"https://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Lucida Grande'; font-size:13pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; font-weight:600;\">Heimdall Homepage:</span></p>\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><a href=\"https://www.glassechidna.com.au/products/heimdall/\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; text-decoration: underline; color:#0000ff;\">https://www.glassechidna.com.au/products/heimdall/</span></a></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px;"
                        " margin-right:0px; -qt-block-indent:0; text-indent:0px; font-family:'MS Shell Dlg 2'; font-size:10pt; text-decoration: underline; color:#0000ff;\"></p></body></html>", nullptr));
        label->setText(QCoreApplication::translate("AboutForm", "<html><head/><body><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; font-weight:600;\">Heimdall and Heimdall Frontend are licensed under the following license:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the &quot;Software&quot;), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">The above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">THE SOFTWARE IS PROVIDED &quot;AS IS&quot;, WITHOUT "
                        "WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.</span></p></body></html>", nullptr));
        label_5->setText(QCoreApplication::translate("AboutForm", "<html><head/><body><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; font-weight:600;\">Heimdall Frontend's user interface is powered by the Qt Framework:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">Copyright \302\251 2008-2011 Nokia Corporation</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">Qt is licensed under the </span><a href=\"https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; text-decoration: underline; color:#0000ff;\">Lesser General Public License v2.1.</span></a></p></body></html>", nullptr));
        label_7->setText(QCoreApplication::translate("AboutForm", "<html><head/><body><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; font-weight:600;\">Heimdall Frontend utilises zlib for package compression:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">zlib is licensed under the following license:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">Copyright \302\251 1995-2010 Jean-loup Gailly and Mark Adler</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">This software is provided 'as-is', without any express or implied warranty. In no event will the authors be held liable for any damages arising from the use of this software.</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">Permission is granted to anyone to use this software for any purpose, including commercial applications, and to alter it and redistribute it freely, subject to the following restrictions:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">1. The origin of"
                        " this software must not be misrepresented; you must not claim that you wrote the original software. If you use this software in a product, an acknowledgment in the product documentation would be appreciated but is not required.</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">2. Altered source versions must be plainly marked as such, and must not be misrepresented as being the original software.</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">3. This notice may not be removed or altered from any source distribution.</span></p></body></html>", nullptr));
        label_8->setText(QCoreApplication::translate("AboutForm", "<html><head/><body><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; font-weight:600;\">Heimdall (command line) utilises libusb for all USB communication:</span></p><p><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt;\">libusb is licensed under the </span><a href=\"https://www.gnu.org/licenses/old-licenses/lgpl-2.1.html\"><span style=\" font-family:'MS Shell Dlg 2'; font-size:10pt; text-decoration: underline; color:#0000ff;\">Lesser General Public License v2.1.</span></a></p></body></html>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class AboutForm: public Ui_AboutForm {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ABOUTFORM_H
